@@ -804,8 +804,9 @@ class mediafile(object):
             self.release=" / ".join(douban_dict['pubdates'])
         if (douban_dict['imdb'].strip()!='') :
             self.imdburl=douban_dict['imdb']
-            self.pathinfo.imdb_url=douban_dict['imdb']
-            logger.info('根据豆瓣信息分析，imdb链接为'+douban_dict['imdb'])
+            self.imdburl='https://www.imdb.com/title/'+self.imdburl+'/'
+            self.pathinfo.imdb_url=self.imdburl
+            logger.info('根据豆瓣信息分析，imdb链接为'+self.imdburl)
         if (douban_dict['episodes']) :
             self.media_type='TV_series'
             self.num=int(douban_dict['episodes'])
